function [t] = test_gp_2d (test_f,TRs,sigma,kernel,kerpar);
% Gaussian Processes Test 1
%
% Parameters: test_f - function to be tested
%             TRs    - number of training samples
%             sigma  - noise on training samples
%             kernel - kernel function to be used
%                      ('linear','poly','rbf')
%             kerpar - kernel function parameter
%                      (ignored for 'linear' case)
% Returns:    running time
%
% Run example:
%   test_gp_2d('test_fn_1d_1',50,4,'poly',5);
%   test_gp_2d('test_fn_2d_1',250,2,'rbf',0.1);

    Ts = 1024; % number of test points

    % training points
    TRx = (rand(TRs,1)-0.5)*8;
    TRy = feval(test_f,TRx) + sigma^2 * randn(TRs,1);

    % test points
    Tx = linspace(-4,4,Ts)';
    Ty = feval(test_f,Tx); % real function values

    global p1;
    p1 = kerpar;
    [t e c] = Q3_gp_regression(TRx,TRy,kernel,Tx,sigma);

    clf;
    plot(Tx,Ty,'r');
    hold on;
    plot(Tx,e,'g');
    plot(TRx,TRy,'b.');
    axis([-4 4 -200 400]);
    title(['GP Estimation of ' test_f],'interpreter','none');
    legend('original function', ...
           'predicted function', ...
           'training points', ...
           'Location','NorthWest');
    hold off;
end

