function [t] = test_gp_3d (test_f,TRs,sigma,kernel,kerpar);
% Gaussian Processes Test 1
%
% Parameters: test_f - function to be tested
%             TRs    - number of training samples
%             sigma  - noise on training samples
%             kernel - kernel function to be used
%             kerpar - kernel function parameter
% Returns:    running time
%
% Run it as
%   test_gp_3d('test_fn_2d_1',100,4,'poly',5);
%   test_gp_3d('test_fn_2d_2',200,1,'rbf',1);

    Ts = 1024; % number of test points

    % training points
    sqrtTRs = round(sqrt(TRs));
    lTRx = (rand(1,sqrtTRs)-0.5)*8;
    lTRy = (rand(1,sqrtTRs)-0.5)*8;
    [TRx,TRy] = meshgrid(lTRx,lTRy);
    TRz = feval(test_f,TRx,TRy); % real training function values
    TRz = TRz + sigma^2 * randn(size(TRz,1),size(TRz,2)); % + noise
    
    % test points
    sqrtTs = round(sqrt(Ts));
    lTx = linspace(-4,4,sqrtTs);
    lTy = linspace(-4,4,sqrtTs);
    [Tx Ty] = meshgrid(lTx,lTy);
    Tz = feval(test_f,Tx,Ty); % real test function values

    global p1;
    p1 = kerpar;
    TRi = [TRx(:),TRy(:)];
    Ti = [Tx(:),Ty(:)];
    [t e c] = Q3_gp_regression(TRi,TRz(:),kernel,Ti,sigma);
    TEz = griddata(Ti(:,1),Ti(:,2),e,Tx,Ty);

    clf;
    surf(Tx,Ty,Tz,'FaceColor','r'); % true surface
    hold on;
    surf(Tx,Ty,TEz,'FaceColor','g'); % predicted surface
    plot3(TRx,TRy,TRz,'marker','o','Markerfacecolor','b','linestyle','none');
    axis([-4 4 -4 4 -20 30]);
    colormap(copper);
    camlight right;
    xlabel('x axis'); ylabel('y axis'); zlabel('z axis');
    title(['GP Estimation of ' test_f],'interpreter','none');
    legend('original function', ...
           'predicted function', ...
           'training points', ...
           'Location', 'NorthWest');
    hold off;
end

